==> nextcloud-27.1.11.tgz: nextcloud/apps/suspicious_login/l10n/ga.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Braitheadh ​​suíomh logáil isteach nua",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Is féidir leat tuilleadh eolais a fháil ach an cnaipe a bhrú a osclóidh %s agus a thaispeánfaidh eolas faoin seoladh IP amhrasach.",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Braitheadh ​​logáil isteach nua ar do chuntas. Rangaíodh an seoladh IP %s mar amhrasach. Más tusa a bhí ann, is féidir leat neamhaird a dhéanamh den teachtaireacht seo. Seachas sin ba cheart duit do phasfhocal a athrú.",
    "More information ↗" : "Tuilleadh eolais ↗",
    "Suspicious Login" : "Logáil Isteach Amhrasacha",
    "New login detected" : "Braitheadh ​​logáil isteach nua",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Braith agus rabhadh a thabhairt faoi IPanna amhrasacha a logáil isteach ar Nextcloud\n\t",
    "Suspicious login detection" : "Brath logáil isteach amhrasach",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Tá an aip logáil isteach amhrasach cumasaithe ar an gcás seo. Coinneoidh sé súil ar sheoltaí IP úsáideoirí logáil isteach go rathúil ó agus tóg aicmitheoir a thugann rabhadh má thagann logáil isteach nua ó sheoladh IP amhrasach.",
    "Training data statistics" : "Staitisticí sonraí oiliúna",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Go dtí seo tá {total} logáil isteach (lena n-áirítear naisc cliant) gafa ag an aip, a bhfuil {distinct} ina n-uigí ar leith (IP, AitheantasÚsáideora).",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Staitisticí samhail aicmitheora",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Níl aon mhúnla aicmitheora oilte fós. Is dócha go gciallaíonn sé seo gur chumasaigh tú an aip le déanaí. Toisc go dteastaíonn sonraí maithe chun samhail a oiliúint, fanann an aip go dtí go mbeidh logáil isteach ar a laghad {days} lá glactha.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Le linn na meastóireachta, léirigh an tsamhail is déanaí (traenáilte {time}) go bhfuil {recall}% de na logáil isteach amhrasach (aisghairm) á ghabháil, ach tá {cruinneas}% de na logáil isteach a rangaítear mar amhrasach amhrasach (cruinneas). Anseo thíos feiceann tú léirshamhlú ar fheidhmíocht samhail stairiúil.",
    "Precision" : "Beachtas",
    "Recall" : "Athghairm"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/suspicious_login/l10n/ga.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Braitheadh ​​suíomh logáil isteach nua",
    "More info about the suspicious IP address available on %s" : "Tuilleadh eolais faoin seoladh IP amhrasach ar fáil ar %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Braitheadh ​​logáil isteach nua ar do chuntas. Rangaíodh an seoladh IP %s mar amhrasach. Más tusa a bhí ann, is féidir leat neamhaird a dhéanamh den teachtaireacht seo. Seachas sin ba cheart duit do phasfhocal a athrú.",
    "Open %s ↗" : "Oscail %s ↗",
    "Suspicious Login" : "Logáil Isteach Amhrasacha",
    "New login detected" : "Braitheadh ​​logáil isteach nua",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Braith agus rabhadh a thabhairt faoi IPanna amhrasacha a logáil isteach ar Nextcloud\n\t",
    "Suspicious login detection" : "Brath logáil isteach amhrasach",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Tá an aip logáil isteach amhrasach cumasaithe ar an gcás seo. Coinneoidh sé súil ar sheoltaí IP úsáideoirí logáil isteach go rathúil ó agus tóg aicmitheoir a thugann rabhadh má thagann logáil isteach nua ó sheoladh IP amhrasach.",
    "Training data statistics" : "Staitisticí sonraí oiliúna",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Go dtí seo tá {total} logáil isteach (lena n-áirítear naisc cliant) gafa ag an aip, a bhfuil {distinct} ina n-uigí ar leith (IP, AitheantasÚsáideora).",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Staitisticí samhail aicmitheora",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Níl aon mhúnla aicmitheora oilte fós. Is dócha go gciallaíonn sé seo gur chumasaigh tú an aip le déanaí. Toisc go dteastaíonn sonraí maithe chun samhail a oiliúint, fanann an aip go dtí go mbeidh logáil isteach ar a laghad {days} lá glactha.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Le linn na meastóireachta, léirigh an tsamhail is déanaí (traenáilte {time}) go bhfuil {recall}% de na logáil isteach amhrasach (aisghairm) á ghabháil, ach tá {cruinneas}% de na logáil isteach a rangaítear mar amhrasach amhrasach (cruinneas). Anseo thíos feiceann tú léirshamhlú ar fheidhmíocht samhail stairiúil.",
    "Precision" : "Beachtas",
    "Recall" : "Athghairm",
    "More information ↗" : "Tuilleadh eolais ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Is féidir leat tuilleadh eolais a fháil ach an cnaipe a bhrú a osclóidh %s agus a thaispeánfaidh eolas faoin seoladh IP amhrasach."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
